@@ -1,6 +1,6 @@
 """Main module."""
 import sys
 sys.path.append('..')
-import pcaconcat 
+from pcaconcat import pcaconcat
 
 
